Learn R Programming

evoper (version 0.6.0)

bestFitness: bestFitness

Description

Given a set S of N solutions created with sortSolution, this function returns the fitness component fot the best solution.

Usage

bestFitness(S)

Value

The best fitness value

Arguments

S

The solution set