f1.rastrigin: f1.rastrigin

View source: R/test-functions.R

f1.rastriginR Documentation

f1.rastrigin

Description

The rastrigin function of N variables for testing optimization methods. The range is xi E [-5.12, 5.12]. The global optima for the function is given by xi = 0, forall i E {1...N}, f(x) = 0.

Usage

f1.rastrigin(x)

Arguments

x

The vector of function parameters

Value

The function value

References

http://deap.gel.ulaval.ca/doc/dev/api/benchmarks.html#deap.benchmarks.rastrigin


evoper documentation built on May 19, 2026, 1:07 a.m.

Related to f1.rastrigin in evoper...