powered by
The rosenbrock function of N variables for testing optimization methods. The global optima for the function is given by xi = 1, forall i E {1...N}, f(x) = 0.
f1.rosenbrockn(x)
The function value
The vector of function parameters
http://deap.gel.ulaval.ca/doc/dev/api/benchmarks.html