getSolution: getSolution

View source: R/helper-functions.R

getSolutionR Documentation

getSolution

Description

Given a set S of N solutions created with sortSolution, this function returns the solution component. A solutions is a set of solutions and their associated fitness

Usage

getSolution(S)

Arguments

S

The solution set

Value

The solution set


evoper documentation built on May 19, 2026, 1:07 a.m.

Related to getSolution in evoper...